/*
** Module   : EventQueue.java
** Abstract : Event queue. 
**
** Copyright (c) 2010-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 SIY 20100629 Created initial version
** 002 SIY 20100804 Changes in imports, some refactorings.
** 003 CA  20130827 Added API to check if the event queue is empty.   
*/

package com.goldencode.p2j.ui.client.event;

import java.util.*;

/**
 * Simple event queue which is able to compress (ignore) empty and identical
 * painting events.
 */
public class EventQueue
{
   /** Backing storage for events. */
   private LinkedList<Event> queue = new LinkedList<Event>();
   
   /**
    * Post specified event into queue.
    * 
    * @param   evt
    *          Event to post.
    */
   public synchronized void post(Event evt)
   {
      if (evt instanceof PaintEvent && !queue.isEmpty())
      {
         if (queue.indexOf(evt) >= 0)
         {
            return;
         }
      }
      queue.add(evt);
   }

   /**
    * Retrieve event from the current active input queue.
    * 
    * @return  event from queue or <code>null</code> if no events are available.
    */
   public synchronized Event get()
   {
      if (queue.isEmpty())
         return null;
      return queue.removeFirst();
   }

   /**
    * Check if the event queue is empty.
    * 
    * @return   <code>true</code> if the event queue is empty or <code>false</code> otherwise.
    */
   public synchronized boolean isEmpty()
   {
      return queue.isEmpty();
   }
   
   /**
    * Install new event queue.
    * 
    * @param   other
    *          New event queue to install.
    */
   public void insert(EventQueue other)
   {
      if (other == null || other.queue.isEmpty())
         return;
      
      while(!queue.isEmpty())
         other.post(queue.removeFirst());
      
      queue = other.queue;
      other.queue = new LinkedList<Event>();
   }
}
